{% extends "multigtfs/base.html" %}
{% block head_title %}{{ block.super }} - Block {{object}}{% endblock %}
{% block page_title %}Block {{object}}{% endblock %}
{% block page_top_content_elem %}
A <strong>Block</strong> represents a fare zone for a trip.
{% endblock %}
{% block page_middle_content %}
<h2>Attributes</h2>
<dl>
    <dt>feed</dt><dd><a href="{% url 'feed_detail' pk=object.feed_id %}">Feed {{object.feed}}</a></dd>
    <dt>id</dt><dd>{{object.id}}</dd>
    <dt>block_id</dt><dd>{{object.block_id}}</dd>
</dl>
{% include "multigtfs/extra_data.html" %}
<h2>Related Objects</h2>
<ul>
    <li><a href="{% url 'trip_by_block_list' feed_id=object.id block_id=object.id %}">{{object.trip_set.count}} Trip{{ object.trip_set.count|pluralize }}</a></li>
</ul>
{% endblock %}
