{% extends "multigtfs/base.html" %}
{% block head_title %}{{ block.super }} - Agencies{% endblock %}
{% block page_title %}Agencies{% endblock %}
{% block page_top_content_elem %}
An <strong>Agency</strong> represents a transit agency.
{% endblock %}
{% block page_middle_content %}
{% for agency in object_list %}
  {% if forloop.first %}<ul>{% endif %}
    <li><a href="{% url 'agency_detail' feed_id=agency.feed_id pk=agency.pk %}">Agency {{ agency }}</a></li>
  {% if forloop.last %}</ul>{% endif %}
{% empty %}
  <p><em>No agencies yet.</em></p>
{% endfor %}
{% endblock %}
