{% load staticfiles %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{% block head_title %}Explore - django-multi-gtfs{% endblock %}</title>
    <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap.min.css">
    <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap-theme.min.css">
    <link rel="stylesheet" href="{% static 'css/explore.css' %}">
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
      <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->
    {% block head_extra %}{% endblock %}
  </head>
  <body>
    <div class="navbar navbar-inverse navbar-fixed-top" role="navigation">
      <div class="container">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
            <span class="sr-only">Toggle navigation</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="navbar-brand" href="{% url 'home' %}">Explore</a>
        </div>
        <div class="collapse navbar-collapse">
          <ul class="nav navbar-nav">
            <li{% block nav_home_active_class %}{% endblock %}><a href="{% url 'home' %}">Home</a></li>
            <li{% block nav_feed_active_class %}{% endblock %}><a href="{% url 'feed_list' %}">Feeds</a></li>
            <li><a href="{% url 'admin:index' %}">Admin</a></li>
          </ul>
        </div>
      </div>
    </div> 
    <div class="container">
      <div class="body-top">
        <h1>{% block page_title %}TODO: set page_title{% endblock %}</h1>
        {% block page_top_content_elem %}
        <p class="lead">
            {% block page_top_content %}TODO: set page_top_content{% endblock %}
        <p>
        {% endblock %}
      </div>
      <div class="body-middle">{% block page_middle_content %}{% endblock %}</div>
    </div>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.11.0/jquery.min.js"></script>
    <script src="//netdna.bootstrapcdn.com/bootstrap/3.1.1/js/bootstrap.min.js"></script>
    {% block body_script %}{% endblock %}
  </body>
</html>
